Handle case when there are no vserver-* packages properly
[sliceimage.git] / build.sh
index c7ba063..f1a0657 100755 (executable)
--- a/build.sh
+++ b/build.sh
@@ -37,6 +37,10 @@ pl_process_fedora_options $@
 shiftcount=$?
 shift $shiftcount
 
+# pldistro expected as $1 - defaults to planetlab
+pldistro=planetlab
+[ -n "$@" ] && pldistro=$1
+
 # Do not tolerate errors
 set -e
 
@@ -52,28 +56,26 @@ vrefname=default
 vref=${vrefdir}/${vrefname}
 install -d -m 755 ${vref}
 
-# "Parse" out the packages and groups for mkfedora
-options=""
-lst="vserver-reference.lst"
-vrefpackages=$(pl_getPackages $lst)
-vrefgroups=$(pl_getGroups $lst)
-for package in ${vrefpackages} ; do  options="$options -p $package"; done
-for group in ${vrefgroups} ; do options="$options -g $group"; done
+# locate the packages and groups file
+pkgsfile=$(pl_locateDistroFile ../build/ ${pldistro} vserver.pkgs)
 
-# Populate a minimal /dev in the reference image
-pl_makedevs ${vref}
+# Some of the PlanetLab RPMs attempt to (re)start themselves in %post,
+# unless the installation is running inside the BootCD environment. We
+# would like to pretend that we are.
+export PL_BOOTCD=1
 
 # Populate image with vserver-reference packages
-pl_setup_chroot ${vref} ${options}
+pl_root_setup_chroot ${vref} -k -f $pkgsfile
 
-for systemvserver in reference-vservers/*.lst ; do
-    NAME=$(basename $systemvserver .lst)
+systemvserver_count=$(ls ../build/config.${pldistro}/vserver-*.pkgs 2> /dev/null | wc -l)
+[ $systemvserver_count -gt 0 ] && for systemvserver in $(ls ../build/config.${pldistro}/vserver-*.pkgs) ; do
+    NAME=$(basename $systemvserver .pkgs | sed -e s,vserver-,,)
 
     echo "--------START BUILDING system vserver ${NAME}: $(date)"
 
     # "Parse" out the packages and groups for yum
-    systempackages=$(pl_getPackages $systemvserver)
-    systemgroups=$(pl_getGroups $systemvserver)
+    systempackages=$(pl_getPackages ${pl_DISTRO_NAME} $systemvserver)
+    systemgroups=$(pl_getGroups ${pl_DISTRO_NAME} $systemvserver)
 
     vdir=${vstubdir}/${NAME}
     rm -rf ${vdir}/*
@@ -87,8 +89,7 @@ for systemvserver in reference-vservers/*.lst ; do
     echo ${vrefname} > ${vdir}.cloned
 
     # Install the system vserver specific packages
-    # xxx - thierry -adding disablerepo for closing the build loop - should be solved some other way
-    [ -n "$systempackages" ] && yum -c ${vdir}/etc/yum.conf --installroot=${vdir} --disablerepo=extras -y install $systempackages
+    [ -n "$systempackages" ] && yum -c ${vdir}/etc/yum.conf --installroot=${vdir} -y install $systempackages
     [ -n "$systemgroups" ] && yum -c ${vdir}/etc/yum.conf --installroot=${vdir} -y groupinstall $systemgroups
 
     # Create a copy of the system vserver w/o the vserver reference files and make it smaller.